@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: dns
 version: 2.0.1
-id: dns-2.0.1-1bad62ddd13b6e401daf614b50d049c4
-key: dns_K29PvNogtzD6wdJWxse4C0
+id: dns-2.0.1-a59fe8f11e1e2b7acb5e4d08faf1d289
+key: dns_5psWVZW3fB85d8ydSTDmMa
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: DNS library in Haskell
@@ -22,15 +22,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/dns-2.0.1
-hs-libraries: HSdns-2.0.1-K29PvNogtzD6wdJWxse4C0
+hs-libraries: HSdns-2.0.1-5psWVZW3fB85d8ydSTDmMa
 depends:
-    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
+    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
-    conduit-extra-1.1.11-b294a7608a3a066998e74974ec65ff9b
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
